@@ -317,7 +317,6 @@ class CloudRunExecuteJobOperator(GoogleCloudBaseOperator):
         if self.operation.metadata.log_uri:
             CloudRunJobLoggingLink.persist(
                 context=context,
-                task_instance=self,
                 log_uri=self.operation.metadata.log_uri,
             )
 
@@ -442,9 +441,10 @@ class CloudRunCreateServiceOperator(GoogleCloudBaseOperator):
                 self.service_name,
                 self.region,
             )
-            return hook.get_service(
+            service = hook.get_service(
                 service_name=self.service_name, region=self.region, project_id=self.project_id
             )
+            return Service.to_dict(service)
         except google.cloud.exceptions.GoogleCloudError as e:
             self.log.error("An error occurred. Exiting.")
             raise e
