@@ -36,6 +36,11 @@ if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
+@deprecated(
+    planned_removal_date="January 3, 2026",
+    use_instead="airflow.providers.google.cloud.operators.gen_ai.generative_model.GenAIGenerateEmbeddingsOperator",
+    category=AirflowProviderDeprecationWarning,
+)
 class TextEmbeddingModelGetEmbeddingsOperator(GoogleCloudBaseOperator):
     """
     Uses the Vertex AI Embeddings API to generate embeddings based on prompt.
@@ -99,6 +104,11 @@ class TextEmbeddingModelGetEmbeddingsOperator(GoogleCloudBaseOperator):
         return response
 
 
+@deprecated(
+    planned_removal_date="January 3, 2026",
+    use_instead="airflow.providers.google.cloud.operators.gen_ai.generative_model.GenAIGenerateContentOperator",
+    category=AirflowProviderDeprecationWarning,
+)
 class GenerativeModelGenerateContentOperator(GoogleCloudBaseOperator):
     """
     Use the Vertex AI Gemini Pro foundation model to generate content.
@@ -178,6 +188,11 @@ class GenerativeModelGenerateContentOperator(GoogleCloudBaseOperator):
         return response
 
 
+@deprecated(
+    planned_removal_date="January 3, 2026",
+    use_instead="airflow.providers.google.cloud.operators.gen_ai.generative_model.GenAISupervisedFineTuningTrainOperator",
+    category=AirflowProviderDeprecationWarning,
+)
 class SupervisedFineTuningTrainOperator(GoogleCloudBaseOperator):
     """
     Use the Supervised Fine Tuning API to create a tuning job.
@@ -280,6 +295,11 @@ class SupervisedFineTuningTrainOperator(GoogleCloudBaseOperator):
         return result
 
 
+@deprecated(
+    planned_removal_date="January 3, 2026",
+    use_instead="airflow.providers.google.cloud.operators.gen_ai.generative_model.GenAICountTokensOperator",
+    category=AirflowProviderDeprecationWarning,
+)
 class CountTokensOperator(GoogleCloudBaseOperator):
     """
     Use the Vertex AI Count Tokens API to calculate the number of input tokens before sending a request to the Gemini API.
@@ -443,6 +463,11 @@ class RunEvaluationOperator(GoogleCloudBaseOperator):
         return response.summary_metrics
 
 
+@deprecated(
+    planned_removal_date="January 3, 2026",
+    use_instead="airflow.providers.google.cloud.operators.gen_ai.generative_model.GenAICreateCachedContentOperator",
+    category=AirflowProviderDeprecationWarning,
+)
 class CreateCachedContentOperator(GoogleCloudBaseOperator):
     """
     Create CachedContent to reduce the cost of requests that contain repeat content with high input token counts.
@@ -522,6 +547,11 @@ class CreateCachedContentOperator(GoogleCloudBaseOperator):
         return cached_content_name
 
 
+@deprecated(
+    planned_removal_date="January 3, 2026",
+    use_instead="airflow.providers.google.cloud.operators.gen_ai.generative_model.GenAIGenerateContentOperator",
+    category=AirflowProviderDeprecationWarning,
+)
 class GenerateFromCachedContentOperator(GoogleCloudBaseOperator):
     """
     Generate a response from CachedContent.
